==> dagger-compiler-2.44-sources.jar: dagger/internal/codegen/binding/AutoValue_MembersInjectionBinding_InjectionSite.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XElement;
import androidx.room.compiler.processing.XTypeElement;
import com.google.common.collect.ImmutableSet;
import com.google.errorprone.annotations.concurrent.LazyInit;
import dagger.spi.model.DependencyRequest;
import java.lang.Override;
import java.lang.SuppressWarnings;

final class AutoValue_MembersInjectionBinding_InjectionSite extends $AutoValue_MembersInjectionBinding_InjectionSite {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile int indexAmongAtInjectMembersWithSameSimpleName;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean indexAmongAtInjectMembersWithSameSimpleName$Memoized;

  AutoValue_MembersInjectionBinding_InjectionSite(MembersInjectionBinding.InjectionSite.Kind kind$,
      XElement element$, XTypeElement enclosingTypeElement$,
      ImmutableSet<DependencyRequest> dependencies$) {
    super(kind$, element$, enclosingTypeElement$, dependencies$);
  }

  @Override
  public int indexAmongAtInjectMembersWithSameSimpleName() {
    if (!indexAmongAtInjectMembersWithSameSimpleName$Memoized) {
      synchronized (this) {
        if (!indexAmongAtInjectMembersWithSameSimpleName$Memoized) {
          indexAmongAtInjectMembersWithSameSimpleName = super.indexAmongAtInjectMembersWithSameSimpleName();
          indexAmongAtInjectMembersWithSameSimpleName$Memoized = true;
        }
      }
    }
    return indexAmongAtInjectMembersWithSameSimpleName;
  }
}

==> dagger-compiler-2.47-sources.jar: dagger/internal/codegen/binding/AutoValue_MembersInjectionBinding_InjectionSite.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XElement;
import androidx.room.compiler.processing.XTypeElement;
import com.google.common.collect.ImmutableSet;
import com.google.errorprone.annotations.concurrent.LazyInit;
import dagger.internal.codegen.model.DependencyRequest;
import java.lang.Override;
import java.lang.SuppressWarnings;

final class AutoValue_MembersInjectionBinding_InjectionSite extends $AutoValue_MembersInjectionBinding_InjectionSite {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile int indexAmongAtInjectMembersWithSameSimpleName;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean indexAmongAtInjectMembersWithSameSimpleName$Memoized;

  AutoValue_MembersInjectionBinding_InjectionSite(MembersInjectionBinding.InjectionSite.Kind kind$,
      XElement element$, XTypeElement enclosingTypeElement$,
      ImmutableSet<DependencyRequest> dependencies$) {
    super(kind$, element$, enclosingTypeElement$, dependencies$);
  }

  @Override
  public int indexAmongAtInjectMembersWithSameSimpleName() {
    if (!indexAmongAtInjectMembersWithSameSimpleName$Memoized) {
      synchronized (this) {
        if (!indexAmongAtInjectMembersWithSameSimpleName$Memoized) {
          indexAmongAtInjectMembersWithSameSimpleName = super.indexAmongAtInjectMembersWithSameSimpleName();
          indexAmongAtInjectMembersWithSameSimpleName$Memoized = true;
        }
      }
    }
    return indexAmongAtInjectMembersWithSameSimpleName;
  }
}
